@@ -36,7 +36,7 @@ namespace and exportable function list
 
 =over 8
 
-=item lazypipe C< LIST >
+=item C< lazypipe LIST >
 
 C< lazypipe > provides a lazy list implementation that will expand generators.
 
@@ -47,30 +47,30 @@ any items until it has to.
 
 C< lazypipe > provides the behavior of the C< lazy > generator.
 
-=item lazyflatten C< LIST >
+=item C< lazyflatten LIST >
 
 C< lazyflatten > is just like C< lazypipe > except it will also expand array
 references and subroutines.
 
 C< lazyflatten > provides the behavior of the C< lazyx > generator.
 
-=item lazy C< LIST >
+=item C< lazy LIST >
 
-=item L C< LIST >
+=item C< L LIST >
 
 C< lazy > is a C< lazypipe > wrapped inside of an iterative generator.
 if C< LIST > is one item, and is already a generator, that generator is
 returned unchanged.
 
-=item lazyx C< LIST >
+=item C< lazyx LIST >
 
-=item Lx C< LIST >
+=item C< Lx LIST >
 
 C< lazyx > is a C< lazyflatten > wrapped inside of an iterative generator.
 if C< LIST > is one item, and is already a generator, that generator is
 returned unchanged.
 
-=item fn C< CODE [ARITY] [RETURNS] >
+=item C< fn CODE [ARITY] [RETURNS] >
 
 C< fn > converts a subroutine into a subroutine with partial application and
 lazy evaluation.
@@ -111,7 +111,7 @@ like the haskell type signature, should you so desire.
 
 most of the functions in L<List::Gen::Haskell> are implemented with C< fn >
 
-=item now C< LIST >
+=item C< now LIST >
 
 sometimes the return values of C< fn {...} > are too lazy.  C< now > will force
 the values in C< LIST > to evaluate, and will return the new list.
@@ -155,29 +155,27 @@ before 5.10.  the corresponding methods can be used instead.
         my ($fetch, $src, $mutable);
         curse {
             next => sub {
-                top: {
-                    until ($size) {
-                        @$pipe or return;
-                        $src = shift @$pipe;
-                        $src = $$src->() if ref $src eq 'List::Gen::Thunk';
-                        ($size, $fetch) = isagen($src) ? do {
-                            $mutable = $src->is_mutable && tied(@$src)->can('fsize');
-                            ($src->size, tied(@$src)->can('FETCH'))
-                        } : (1, undef)
-                    }
-                    if ($fetch) {
-                        my $got = cap $fetch->(undef, $pos);
-                        $size = $mutable->() if $mutable;
-                        if ($size <= $pos) {
-                            $size = $pos = 0;
-                            redo top;
-                        }
-                        $size = $pos = 0     if ++$pos >= $size;
-                        return wantarray ? @$got : pop @$got;
-                    } else {
-                        $size = 0;
-                        return $src
+                top: until ($size) {
+                    @$pipe or return;
+                    $src = shift @$pipe;
+                    $src = $$src->() if ref $src eq 'List::Gen::Thunk';
+                    ($size, $fetch) = isagen($src) ? do {
+                        $mutable = $src->is_mutable && tied(@$src)->can('fsize');
+                        ($src->size, tied(@$src)->can('FETCH'))
+                    } : (1, undef)
+                }
+                if ($fetch) {
+                    my $got = cap $fetch->(undef, $pos);
+                    $size = $mutable->() if $mutable;
+                    if ($size <= $pos) {
+                        $size = $pos = 0;
+                        goto top;
                     }
+                    $size = $pos = 0     if ++$pos >= $size;
+                    return wantarray ? @$got : pop @$got;
+                } else {
+                    $size = 0;
+                    return $src
                 }
             },
             more => sub {@$pipe or $pos < $size},
@@ -188,60 +186,58 @@ before 5.10.  the corresponding methods can be used instead.
         my ($pipe, $pos, $size) = (\@_, 0, 0);
         my ($type, $src, $ref, $mutable);
         my $next = sub {
-            shift_pipe: {
-                until ($size) {
-                    @$pipe or return;
-                    $src = shift @$pipe;
-                    $src = $$src->() if ref $src eq 'List::Gen::Thunk';
-                    ($size, $type) = do {
-                        if ($ref = ref $src) {
-                            if ($ref eq 'ARRAY') {
-                                (0 + @$src, 'array')
-                            }
-                            elsif (List::Gen::isagen $src) {
-                                $mutable = tied(@$src)->mutable;
-                                ($src->size, 'gen')
-                            }
-                            elsif (eval {$src->isa('List::Gen::Pipe')}) {
-                                ($src->more, 'pipe')
-                            }
-                            else {1}
+            shift_pipe: until ($size) {
+                @$pipe or return;
+                $src = shift @$pipe;
+                $src = $$src->() if ref $src eq 'List::Gen::Thunk';
+                ($size, $type) = do {
+                    if ($ref = ref $src) {
+                        if ($ref eq 'ARRAY') {
+                            (0 + @$src, 'array')
+                        }
+                        elsif (List::Gen::isagen $src) {
+                            $mutable = tied(@$src)->mutable;
+                            ($src->size, 'gen')
+                        }
+                        elsif (eval {$src->isa('List::Gen::Pipe')}) {
+                            ($src->more, 'pipe')
                         }
                         else {1}
                     }
+                    else {1}
                 }
-                my $got;
-                if ($type) {
-                    if ($type eq 'array') {
-                        $got  = \$$src[$pos]
-                    }
-                    elsif ($type eq 'gen') {
-                        $got  = \$src->get($pos);
-                        $size = $src->size if $mutable;
-                        if ($pos >= $size) {
-                            redo shift_pipe;
-                        }
-                    }
-                    else {
-                        $got  = \$src->next;
-                        $size = $src->more
-                    }
-                } else {
-                    if ($ref eq 'CODE') {
-                        defined ${$got = \$src->()}
-                            ? $pos--
-                            : do {
-                                $pos = $size = 0;
-                                redo shift_pipe;
-                            }
-                    }
-                    else {$got = \$src}
-                }
-                if (++$pos >= $size) {
-                      $pos  = $size = 0
-                }
-                $$got
             }
+            my $got;
+            if ($type) {
+                if ($type eq 'array') {
+                    $got  = \$$src[$pos]
+                }
+                elsif ($type eq 'gen') {
+                    $got  = \$src->get($pos);
+                    $size = $src->size if $mutable;
+                    if ($pos >= $size) {
+                        goto shift_pipe
+                    }
+                }
+                else {
+                    $got  = \$src->next;
+                    $size = $src->more
+                }
+            } else {
+                if ($ref eq 'CODE') {
+                    defined ${$got = \$src->()}
+                        ? $pos--
+                        : do {
+                            $pos = $size = 0;
+                            goto shift_pipe
+                        }
+                }
+                else {$got = \$src}
+            }
+            if (++$pos >= $size) {
+                  $pos  = $size = 0
+            }
+            $$got
         };
         curse {
             next  => $next,
